@@ -4,9 +4,9 @@ import grpc
 import uuid
 
 class ValidationInterceptor(ClientInterceptor):
-    def __init__(self, token):
+    def __init__(self, token, instance):
         self.token = token
-        self.instance = uuid.uuid4()
+        self.instance = str(uuid.uuid4()) if instance is None else instance
 
     def intercept(self, method: Callable, request_or_iterator: Any, call_details: grpc.ClientCallDetails):
         new_details = ClientCallDetails(
